.. SPDX-FileCopyrightText: 2021-2022 Constantine Evans <const@costi.eu>
..
.. SPDX-License-Identifier: AGPL-3.0-only

.. _commandline:

Command-line Interface
======================

.. click:: qslib.cli:cli
   :prog: qslib
   :nested: full
